'use client'

import { useEffect, useState } from 'react'
import { useUser } from '@/contexts/UserContext'
import { useTheme } from '@/contexts/ThemeContext'
import { useRouter, usePathname } from 'next/navigation'

const publicPaths = ['/login', '/register', '/forgot-password', '/']

export default function AuthGuard({ children }: { children: React.ReactNode }) {
  const { isAuthenticated, isLoading: userLoading } = useUser()
  const { isLoading: themeLoading } = useTheme()
  const router = useRouter()
  const pathname = usePathname()
  const [isAuthorized, setIsAuthorized] = useState(false)

  useEffect(() => {
    if (!userLoading && !themeLoading) {
      if (publicPaths.includes(pathname)) {
        if (isAuthenticated) {
          router.push('/dashboard')
        } else {
          setIsAuthorized(true)
        }
      } else {
        if (!isAuthenticated) {
          router.push('/')
        } else {
          setIsAuthorized(true)
        }
      }
    }
  }, [isAuthenticated, pathname, router, userLoading, themeLoading])

  // Loading ekranı
  if (userLoading || themeLoading || !isAuthorized) {
    return (
      <div className="fixed inset-0 bg-white dark:bg-slate-900 z-50 flex items-center justify-center">
        <div className="flex flex-col items-center gap-3">
          <div className="w-16 h-16 rounded-xl bg-gradient-to-br from-fuchsia-500 to-purple-500 p-3 shadow-lg animate-pulse">
            <div className="w-full h-full rounded-lg bg-white/20" />
          </div>
          <div className="text-sm font-medium text-slate-600 dark:text-slate-400">
            Yükleniyor...
          </div>
        </div>
      </div>
    )
  }

  return <>{children}</>
} 